<?php
/**
 * Gutenbee functions and definitions
 */

if ( ! defined( 'GUTENBEE_NAME' ) ) {
	define( 'GUTENBEE_NAME', 'gutenbee' );
}

if ( ! function_exists( 'gutenbee_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function gutenbee_setup() {
	// Default content width.
	$GLOBALS['content_width'] = 960;

	// Make theme available for translation.
	load_theme_textdomain( 'gutenbee', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// Let WordPress manage the document title.
	add_theme_support( 'title-tag' );

	// Enable support for Post Thumbnails on posts and pages.
	add_theme_support( 'post-thumbnails' );

	register_nav_menu( 'menu-1', esc_html__( 'Main Menu', 'gutenbee' ) );
	register_nav_menu( 'menu-2', esc_html__( 'Main Menu - Right', 'gutenbee' ) );

	// Switch default core markup for search form, comment form, and comments to output valid HTML5.
	add_theme_support( 'html5', apply_filters( 'gutenbee_add_theme_support_html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) ) );

	// Add theme support for custom logos.
	add_theme_support( 'custom-logo', apply_filters( 'gutenbee_add_theme_support_custom_logo', array() ) );

	add_theme_support( 'custom-background', array(
		'default-color' => gutenbee_customizer_defaults( 'background_color' ),
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	// Image sizes
	set_post_thumbnail_size( 960, 540, true );
	add_image_size( 'gutenbee_item', 615, 346, true );
	add_image_size( 'gutenbee_item_tall', 615 );
	add_image_size( 'gutenbee_item_lg', 1260, 709, true );
	add_image_size( 'gutenbee_article_media', 510, 510, true );

	add_theme_support( 'editor-styles' );
	add_editor_style( 'css/admin/editor-styles.min.css' );

}
endif;
add_action( 'after_setup_theme', 'gutenbee_setup' );


/**
 * Theme layout information.
 */
require_once get_theme_file_path( '/inc/layout.php' );

/**
 * Various helper functions, so that this functions.php is cleaner.
 */
require_once get_theme_file_path( '/inc/helpers.php' );

/**
 * Scripts and styles.
 */
require_once get_theme_file_path( '/inc/scripts-styles.php' );

/**
 * Sidebars and widgets.
 */
require_once get_theme_file_path( '/inc/sidebars-widgets.php' );

/**
 * Hooks.
 */
require_once get_theme_file_path( '/inc/default-hooks.php' );

/**
 * Template tags.
 */
require_once get_theme_file_path( '/inc/template-tags.php' );

/**
 * Sanitization functions.
 */
require_once get_theme_file_path( '/inc/sanitization.php' );

/**
 * Customizer defaults, settings, controls, etc.
 */
require_once get_theme_file_path( '/inc/customizer/customizer.php' );

/**
 * Custom fields.
 */
require_once get_theme_file_path( '/inc/custom-fields.php' );

/**
 * Fonts list.
 */
require_once get_theme_file_path( '/inc/class-fonts-list.php' );

/**
 * SCSS Colors reader.
 */
require_once get_theme_file_path( '/inc/class-scss-colors.php' );

/**
 * User onboarding.
 */
require_once get_theme_file_path( '/inc/onboarding.php' );

/**
 * WooCommerce integration.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require_once get_theme_file_path( '/inc/woocommerce.php' );
}

/**
 * GutenBee related code.
 */
require_once get_theme_file_path( '/inc/gutenbee.php' );

/**
 * Jetpack integration.
 */
require_once get_theme_file_path( '/inc/jetpack.php' );

