<?php
/**
 * Range Customizer Control
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WP_Customize_Control' ) ) {
	return null;
}

class Gutenbee_Customize_Range_Control extends WP_Customize_Control {
	/**
	 * The type of control.
	 *
	 * @access public
	 * @var string
	 */
	public $type = 'gutenbee-range';

	public $responsive = true;

	/**
	 * Enqueue scripts and styles.
	 *
	 * @access public
	 * @return void
	 */
	public function enqueue() {
		$theme = wp_get_theme();

		wp_enqueue_script( $this->type . '-customize-control', get_theme_file_uri( '/inc/customizer/controls/range/customizer.js' ), array( 'jquery' ), $theme->get( 'Version' ), true );
	}

	/**
	 * Refresh the parameters passed to the JavaScript via JSON.
	 *
	 * @access public
	 * @return void
	 */
	public function to_json() {
		parent::to_json();

		$this->json['id']         = $this->id;
		$this->json['link']       = $this->get_link();
		$this->json['inputAttrs'] = $this->input_attrs;

		$values = $this->value();
		if ( ! $this->responsive ) {
			unset( $values['tablet'], $values['mobile'] );
		}
		$this->json['values'] = $values;

		$this->json['responsive'] = $this->responsive;
	}

	/**
	 * Don't render anything with PHP as rendering is handled via JS templates.
	 *
	 * @access public
	 */
	public function render_content() { }

	/**
	 * The Underscore (JS) template for this control's content.
	 *
	 * @access protected
	 * @return void
	 */
	protected function content_template() {
		?>
		<div class="gutenbee-control-range-wrap">
			<# if ( data.label ) { #>
				<label
					id="{{data.id}}-label"
					for="{{data.id}}-range-input"
					class="customize-control-title"
				>
					{{ data.label }}
				</label>
			<# } #>

			<# if ( data.description ) { #>
				<span class="description customize-control-description">{{ data.description }}</span>
			<# } #>

			<# if ( data.responsive ) { #>
				<div class="button-group-devices">
					<button type="button" data-device="desktop" class="preview-desktop active">
						<span class="screen-reader-text"><?php echo esc_html_x( 'Desktop', 'device', 'gutenbee' ); ?></span>
					</button>
					<button type="button" data-device="tablet" class="preview-tablet">
						<span class="screen-reader-text"><?php echo esc_html_x( 'Tablet', 'device', 'gutenbee' ); ?></span>
					</button>
					<button type="button" data-device="mobile" class="preview-mobile">
						<span class="screen-reader-text"><?php echo esc_html_x( 'Mobile', 'device', 'gutenbee' ); ?></span>
					</button>
				</div>
			<# } #>

			<div class="gutenbee-control-range-breakpoint-wrap">
				<# _.each( data.values, function ( value, breakpoint ) { #>
					<div
						class="gutenbee-control-range gutenbee-responsive-controls-{{breakpoint}}"
						data-breakpoint="{{breakpoint}}"
					>
						<div class="gutenbee-control-range-slider">
							<input
								type="range"
								aria-labelledby="{{data.id}}-{{breakpoint}}-label"
								name="{{data.id}}-{{breakpoint}}-range-slider-input"
								id="{{data.id}}-{{breakpoint}}-range-slider-input"
								class="gutenbee-control-range-slider-input"
								min="{{data.inputAttrs.min}}"
								max="{{data.inputAttrs.max}}"
								step="{{data.inputAttrs.step}}"
								value={{value}}
								placeholder="0"
							>
						</div>

						<input
							type="number"
							name="{{data.id}}-{{breakpoint}}-range-input"
							id="{{data.id}}-{{breakpoint}}-range-input"
							class="gutenbee-control-range-input"
							min="{{data.inputAttrs.min}}"
							max="{{data.inputAttrs.max}}"
							step="{{data.inputAttrs.step}}"
							value="{{value}}"
						>
					</div>
				<# } ); #>
			</div>

			<input class="gutenbee-range-control-hidden-value" type="hidden" {{{ data.link }}}>
		</div>
		<?php
	}
}
