<?php
/**
 * Standard Customizer Sections and Settings
 */

add_action( 'customize_register', 'gutenbee_customize_register' );
/**
 * Registers Customizer panels, sections, and controls.
 *
 * @param WP_Customize_Manager $wp_customize Reference to the customizer's manager object.
 */
function gutenbee_customize_register( $wp_customize ) {
	// Partial for various settings that affect the customizer styles, but can't have a dedicated icon, e.g. typography controls.
	$wp_customize->selective_refresh->add_partial( 'theme_style', array(
		'selector'            => '#gutenbee-style-inline-css',
		'render_callback'     => 'gutenbee_get_all_customizer_css',
		'settings'            => array_keys( gutenbee_get_registered_typography_controls() ),
		'container_inclusive' => false,
	) );

	$wp_customize->selective_refresh->add_partial( 'theme_gfonts', array(
		'selector'            => '#gutenbee-user-google-fonts-css',
		'render_callback'     => 'gutenbee_customize_preview_google_fonts',
		'settings'            => array_keys( gutenbee_get_registered_typography_controls() ),
		'container_inclusive' => true,
	) );

	// This partial needs to be available for both tob_bar and header options.
	$wp_customize->selective_refresh->add_partial( 'header_layout', array(
		'selector'            => '.site-header',
		'render_callback'     => 'gutenbee_header',
		'settings'            => array(),
		'container_inclusive' => true,
	) );



	//
	// Global
	//
	$wp_customize->add_panel( 'global', array(
		'title'    => esc_html_x( 'Global', 'customizer section title', 'gutenbee' ),
		'priority' => 1,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/global/layout.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/global/colors.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/global/typography.php' );



	//
	// Header Options
	//
	$wp_customize->add_panel( 'header', array(
		'title'    => esc_html_x( 'Header', 'customizer section title', 'gutenbee' ),
		'priority' => 3,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/header/layout.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/header/content.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/header/colors.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/header/colors-transparent.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/header/colors-sticky.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/header/colors-mobile-nav.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/header/typography.php' );



	//
	// Blog Options
	//
	$wp_customize->add_panel('blog', array(
		'title'    => esc_html_x( 'Blog', 'customizer section title', 'gutenbee' ),
		'priority' => 5,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/blog/layout.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/blog/content.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/blog/typography.php' );



	//
	// Footer Options
	//
	$wp_customize->selective_refresh->add_partial( 'footer_layout', array(
		'selector'            => '.site-footer',
		'render_callback'     => 'gutenbee_footer',
		'settings'            => array(),
		'container_inclusive' => true,
	) );

	$wp_customize->add_panel( 'footer', array(
		'title'    => esc_html_x( 'Footer', 'customizer section title', 'gutenbee' ),
		'priority' => 7,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/footer/layout.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/footer/colors.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/footer/typography.php' );



	//
	// Utilities
	//
	$wp_customize->add_panel( 'utilities', array(
		'title'    => esc_html_x( 'Utilities', 'customizer section title', 'gutenbee' ),
		'priority' => 10,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/utilities/lightbox.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/utilities/button-top.php' );
	require_once get_theme_file_path( '/inc/customizer/sections/utilities/assets.php' );



	//
	// Site Identity
	//
	$wp_customize->selective_refresh->add_partial( 'site_branding', array(
		'selector'            => '.site-branding',
		'render_callback'     => 'gutenbee_the_site_branding',
		'settings'            => array( 'custom_logo' ),
		'container_inclusive' => true,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/site-identity.php' );


	//
	// WooCommerce
	//
	if ( class_exists( 'WooCommerce' ) ) {
		require_once get_theme_file_path( 'inc/customizer/sections/woocommerce/single-product.php' );
	}


}

add_action( 'customize_preview_init', 'gutenbee_customize_preview_js' );
/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function gutenbee_customize_preview_js() {
	// Generic preview code.
	wp_enqueue_script( 'gutenbee-customizer-preview', get_theme_file_uri( '/inc/customizer/preview/preview.js' ), array( 'jquery' ), gutenbee_asset_version(), true );
	wp_enqueue_style( 'gutenbee-customizer-preview', get_theme_file_uri( '/inc/customizer/preview/preview.css' ), array(), gutenbee_asset_version() );

	// Options-specific preview code.
	wp_enqueue_script( 'gutenbee-customizer-preview-global', get_theme_file_uri( '/inc/customizer/preview/global.js' ), array( 'jquery' ), gutenbee_asset_version(), true );
	wp_enqueue_script( 'gutenbee-customizer-preview-header', get_theme_file_uri( '/inc/customizer/preview/header.js' ), array( 'jquery' ), gutenbee_asset_version(), true );
	wp_enqueue_script( 'gutenbee-customizer-preview-blog', get_theme_file_uri( '/inc/customizer/preview/blog.js' ), array( 'jquery' ), gutenbee_asset_version(), true );
	wp_enqueue_script( 'gutenbee-customizer-preview-footer', get_theme_file_uri( '/inc/customizer/preview/footer.js' ), array( 'jquery' ), gutenbee_asset_version(), true );
	wp_enqueue_script( 'gutenbee-customizer-preview-utilities', get_theme_file_uri( '/inc/customizer/preview/utilities.js' ), array( 'jquery' ), gutenbee_asset_version(), true );
}


add_action( 'customize_register', 'gutenbee_customize_register_custom_controls', 9 );
/**
 * Registers custom Customizer controls.
 *
 * @param WP_Customize_Manager $wp_customize Reference to the customizer's manager object.
 */
function gutenbee_customize_register_custom_controls( $wp_customize ) {

	require_once get_theme_file_path( '/inc/customizer/controls/section-header/section-header.php' );
	require_once get_theme_file_path( '/inc/customizer/controls/notice/notice.php' );

	// Only call $wp_customize->register_control_type() on JS-rendered controls.
	require_once get_theme_file_path( '/inc/customizer/controls/range/range.php' );
	$wp_customize->register_control_type( 'Gutenbee_Customize_Range_Control' );

	require_once get_theme_file_path( '/inc/customizer/controls/color/color.php' );
	$wp_customize->register_control_type( 'Gutenbee_Customize_Color_Control' );

	require_once get_theme_file_path( '/inc/customizer/controls/typography/typography.php' );
	$wp_customize->register_control_type( 'Gutenbee_Customize_Typography_Control' );

	require_once get_theme_file_path( '/inc/customizer/controls/spacing/spacing.php' );
	$wp_customize->register_control_type( 'Gutenbee_Customize_Spacing_Control' );

	require_once get_theme_file_path( '/inc/customizer/controls/image-bg/image-bg.php' );
	$wp_customize->register_control_type( 'Gutenbee_Customize_Image_BG_Control' );
}


add_action( 'customize_controls_enqueue_scripts', 'gutenbee_customize_controls_js' );
/**
 * Registers/Enqueues styles and scripts for customizer controls.
 *
 */
function gutenbee_customize_controls_js() {
	wp_enqueue_style( 'gutenbee-customizer-controls', get_theme_file_uri( '/inc/customizer/controls/style.css' ), array(), gutenbee_asset_version() );
	wp_enqueue_script( 'gutenbee-customizer-controls', get_theme_file_uri( '/inc/customizer/controls/scripts.js' ), array(), gutenbee_asset_version(), true );
}


/**
 * Helpers
 */

function gutenbee_customizer_defaults_empty_breakpoints( $override_breakpoints = array() ) {
	return array_merge( array(
		'desktop' => '',
		'tablet'  => '',
		'mobile'  => '',
	), $override_breakpoints );
}

function gutenbee_customizer_defaults_same_value_breakpoints( $value ) {
	return array(
		'desktop' => $value,
		'tablet'  => $value,
		'mobile'  => $value,
	);
}

function gutenbee_sanitize_range_control_breakpoints( $value ) {
	if ( ! empty( $value ) && is_string( $value ) ) {
		$value = json_decode( $value, true );
	}

	if ( ! is_array( $value ) ) {
		return gutenbee_customizer_defaults_empty_breakpoints();
	}

	$value = array_map( 'gutenbee_sanitize_intval_or_empty', $value );

	return $value;
}

function gutenbee_spacing_control_defaults_empty_breakpoints( $override_breakpoints = array() ) {
	$defaults = array(
		'desktop' => array(
			'top'    => '',
			'right'  => '',
			'bottom' => '',
			'left'   => '',
			'linked' => false,
		),
		'tablet'  => array(
			'top'    => '',
			'right'  => '',
			'bottom' => '',
			'left'   => '',
			'linked' => false,
		),
		'mobile'  => array(
			'top'    => '',
			'right'  => '',
			'bottom' => '',
			'left'   => '',
			'linked' => false,
		),
	);

	$return = array();
	foreach ( $defaults as $breakpoint => $values ) {
		if ( isset( $override_breakpoints[ $breakpoint ] ) && is_array( $override_breakpoints[ $breakpoint ] ) ) {
			$return[ $breakpoint ] = array_merge( $values, $override_breakpoints[ $breakpoint ] );
		} else {
			$return[ $breakpoint ] = $values;
		}
	}

	return $return;
}

function gutenbee_sanitize_spacing_control_breakpoints( $values ) {
	$defaults = gutenbee_spacing_control_defaults_empty_breakpoints();

	if ( ! empty( $values ) && is_string( $values ) ) {
		$values = json_decode( $values, true );
	}

	if ( ! is_array( $values ) ) {
		return $defaults;
	}

	$values = wp_parse_args( $values, $defaults );

	foreach ( $values as $breakpoint => $value ) {
		if ( ! array_key_exists( $breakpoint, $defaults ) ) {
			unset( $values[ $breakpoint ] );
		}
	}

	$new_values = array();

	foreach ( $values as $breakpoint => $breakpoint_values ) {
		if ( array_key_exists( $breakpoint, $defaults ) ) {
			$new_breakpoint_values = wp_parse_args( $breakpoint_values, $defaults[ $breakpoint ] );

			$linked = $new_breakpoint_values['linked'];

			unset( $new_breakpoint_values['linked'] );

			$new_breakpoint_values = array_map( 'gutenbee_sanitize_intval_or_empty', $new_breakpoint_values );

			$new_breakpoint_values['linked'] = (bool) $linked;

			$new_values[ $breakpoint ] = $new_breakpoint_values;
		}
	}

	return $new_values;
}

function gutenbee_typography_control_defaults_empty_breakpoints( $override_breakpoints = array() ) {
	$defaults = array(
		'desktop' => array(
			'family'     => '',
			'variant'    => '',
			'size'       => '',
			'lineHeight' => '',
			'transform'  => '',
			'spacing'    => '',
			'is_gfont'   => false,
		),
		'tablet'  => array(
			'family'     => '',
			'variant'    => '',
			'size'       => '',
			'lineHeight' => '',
			'transform'  => '',
			'spacing'    => '',
			'is_gfont'   => false,
		),
		'mobile'  => array(
			'family'     => '',
			'variant'    => '',
			'size'       => '',
			'lineHeight' => '',
			'transform'  => '',
			'spacing'    => '',
			'is_gfont'   => false,
		),
	);

	$return = array();
	foreach ( $defaults as $breakpoint => $values ) {
		if ( isset( $override_breakpoints[ $breakpoint ] ) && is_array( $override_breakpoints[ $breakpoint ] ) ) {
			$return[ $breakpoint ] = array_merge( $values, $override_breakpoints[ $breakpoint ] );
		} else {
			$return[ $breakpoint ] = $values;
		}
	}

	return $return;
}

function gutenbee_sanitize_typography_control_breakpoints( $values ) {
	$defaults = gutenbee_typography_control_defaults_empty_breakpoints();

	if ( ! empty( $values ) && is_string( $values ) ) {
		$values = json_decode( $values, true );
	}

	if ( ! is_array( $values ) ) {
		return $defaults;
	}

	$values = wp_parse_args( $values, $defaults );

	foreach ( $values as $breakpoint => $value ) {
		if ( ! array_key_exists( $breakpoint, $defaults ) ) {
			unset( $values[ $breakpoint ] );
		}
	}

	$new_values = array();

	foreach ( $values as $breakpoint => $breakpoint_values ) {
		if ( array_key_exists( $breakpoint, $defaults ) ) {
			$new_breakpoint_values = wp_parse_args( $breakpoint_values, $defaults[ $breakpoint ] );

			$new_breakpoint_values['family']     = sanitize_text_field( $new_breakpoint_values['family'] );
			$new_breakpoint_values['variant']    = sanitize_text_field( $new_breakpoint_values['variant'] );
			$new_breakpoint_values['size']       = gutenbee_sanitize_intval_or_empty( $new_breakpoint_values['size'] );
			$new_breakpoint_values['lineHeight'] = gutenbee_sanitize_floatval_or_empty( $new_breakpoint_values['lineHeight'] );
			$new_breakpoint_values['transform']  = sanitize_text_field( $new_breakpoint_values['transform'] );
			$new_breakpoint_values['spacing']    = gutenbee_sanitize_floatval_or_empty( $new_breakpoint_values['spacing'] );
			$new_breakpoint_values['is_gfont']   = (bool) intval( $new_breakpoint_values['is_gfont'] );

			$new_values[ $breakpoint ] = $new_breakpoint_values;
		}
	}

	return $new_values;
}

function gutenbee_image_bg_control_defaults( $override_values = array() ) {
	return array_merge( array(
		'image_id'       => '',
		'image_url'      => '',
		'repeat'         => 'no-repeat',
		'position'       => 'center top',
		'attachment'     => 'scroll',
		'size'           => 'cover',
		'parallax'       => false,
		'parallax_speed' => 0.3,
	), $override_values );
}

function gutenbee_sanitize_image_bg_control( $values ) {
	$defaults = gutenbee_image_bg_control_defaults();

	if ( ! empty( $values ) && is_string( $values ) ) {
		$values = json_decode( $values, true );
	}

	if ( ! is_array( $values ) ) {
		return $defaults;
	}

	$values = wp_parse_args( $values, $defaults );

	$new_values = array();

	$new_values['image_id']       = gutenbee_sanitize_intval_or_empty( $values['image_id'] );
	$new_values['image_url']      = esc_url_raw( $values['image_url'] );
	$new_values['repeat']         = gutenbee_sanitize_image_repeat( $values['repeat'] );
	$new_values['position']       = gutenbee_sanitize_image_position( $values['position'] );
	$new_values['attachment']     = gutenbee_sanitize_image_attachment( $values['attachment'] );
	$new_values['size']           = gutenbee_sanitize_image_size( $values['size'] );
	$new_values['parallax']       = (bool) intval( $values['parallax'] );
	$new_values['parallax_speed'] = floatval( $values['parallax_speed'] );

	return $new_values;
}


/**
 * Customizer defaults.
 */
require_once get_theme_file_path( '/inc/customizer/defaults.php' );

/**
 * Customizer partial callbacks.
 */
require_once get_theme_file_path( '/inc/customizer/partial-callbacks.php' );

/**
 * CSS Generator.
 */
require_once get_theme_file_path( '/inc/customizer/class-gutenbee-customizer-css-generator.php' );

/**
 * Customizer generated styles.
 */
require_once get_theme_file_path( '/inc/customizer/generated-styles.php' );
