<?php
function gutenbee_include_generated_styles_files() {
	require_once get_theme_file_path( '/inc/customizer/generated-styles/global.php' );
	require_once get_theme_file_path( '/inc/customizer/generated-styles/header.php' );
	require_once get_theme_file_path( '/inc/customizer/generated-styles/blog.php' );
	require_once get_theme_file_path( '/inc/customizer/generated-styles/footer.php' );
	require_once get_theme_file_path( '/inc/customizer/generated-styles/site-identity.php' );
	require_once get_theme_file_path( '/inc/customizer/generated-styles/utilities.php' );
}

function gutenbee_get_registered_typography_controls() {
	$controls = array(
		'global_typo_body'            => gutenbee_customizer_defaults( 'global_typo_body' ),
		'global_typo_h1'              => gutenbee_customizer_defaults( 'global_typo_h1' ),
		'global_typo_h2'              => gutenbee_customizer_defaults( 'global_typo_h2' ),
		'global_typo_h3'              => gutenbee_customizer_defaults( 'global_typo_h3' ),
		'global_typo_h4'              => gutenbee_customizer_defaults( 'global_typo_h4' ),
		'global_typo_h5'              => gutenbee_customizer_defaults( 'global_typo_h5' ),
		'global_typo_h6'              => gutenbee_customizer_defaults( 'global_typo_h6' ),
		'global_typo_form_labels'     => gutenbee_customizer_defaults( 'global_typo_form_labels' ),
		'global_typo_form_text'       => gutenbee_customizer_defaults( 'global_typo_form_text' ),
		'global_typo_buttons'         => gutenbee_customizer_defaults( 'global_typo_buttons' ),
		'header_typo_logo'            => gutenbee_customizer_defaults( 'header_typo_logo' ),
		'header_typo_tagline'         => gutenbee_customizer_defaults( 'header_typo_tagline' ),
		'header_typo_menu'            => gutenbee_customizer_defaults( 'header_typo_menu' ),
		'header_typo_submenu'         => gutenbee_customizer_defaults( 'header_typo_submenu' ),
		'footer_typo_widget_title'    => gutenbee_customizer_defaults( 'footer_typo_widget_title' ),
		'footer_typo_widget_text'     => gutenbee_customizer_defaults( 'footer_typo_widget_text' ),
		'blog_typo_archives_title'    => gutenbee_customizer_defaults( 'blog_typo_archives_title' ),
		'blog_typo_archives_meta'     => gutenbee_customizer_defaults( 'blog_typo_archives_meta' ),
		'blog_typo_archives_content'  => gutenbee_customizer_defaults( 'blog_typo_archives_content' ),
		'blog_typo_archives_button'   => gutenbee_customizer_defaults( 'blog_typo_archives_button' ),
		'blog_typo_single_post_title' => gutenbee_customizer_defaults( 'blog_typo_single_post_title' ),
		'blog_typo_single_post_meta'  => gutenbee_customizer_defaults( 'blog_typo_single_post_meta' ),
		'blog_typo_single_post_tags'  => gutenbee_customizer_defaults( 'blog_typo_single_post_tags' ),
	);

	return apply_filters( 'gutenbee_registered_typography_controls', $controls );
}

function gutenbee_enqueue_google_fonts() {
	$css = Gutenbee_Customizer_CSS_Generator::get_instance();

	if ( is_customize_preview() ) {
		$css->register_typography_control( 'placeholder_preview_font', gutenbee_typography_control_defaults_empty_breakpoints( array(
			'desktop' => array(
				'family'     => 'Open Sans',
				'variant'    => 'regular',
				'size'       => '',
				'lineHeight' => '',
				'transform'  => '',
				'spacing'    => '',
				'is_gfont'   => true,
			),
		) ) );
	}

	foreach ( gutenbee_get_registered_typography_controls() as $option => $default ) {
		$css->register_typography_control( $option, $default );
	}

	$url = $css->get_google_fonts_url();
	if ( ! empty( $url ) && ! has_action( 'wp_head', 'gutenbee_head_preconnect_google_fonts' ) ) {
		add_action( 'wp_head', 'gutenbee_head_preconnect_google_fonts' );
	}

	wp_enqueue_style( 'gutenbee-user-google-fonts', $url, array(), gutenbee_asset_version() );
}

add_filter( 'gutenbee_customizer_css_generator_add_font_to_url', 'gutenbee_disable_gfonts_add_font_to_url', 10, 3 );
function gutenbee_disable_gfonts_add_font_to_url( $add, $option_name, $default ) {
	// Don't fiddle with the value if it isn't directly affected by this options.
	if ( get_theme_mod( 'global_typo_disable_google_fonts', gutenbee_customizer_defaults( 'global_typo_disable_google_fonts' ) ) ) {
		$add = false;
	}

	return $add;
}

add_filter( 'gutenbee_customizer_css_generator_generate_typography_stack', 'gutenbee_disable_gfonts_font_family', 10, 3 );
function gutenbee_disable_gfonts_font_family( $stack, $values, $fallback_stack ) {
	if ( ! get_theme_mod( 'global_typo_disable_google_fonts', gutenbee_customizer_defaults( 'global_typo_disable_google_fonts' ) ) ) {
		return $stack;
	}

	if ( array_key_exists( 'is_gfont', $values ) && true === $values['is_gfont'] ) {
		// Remove the first font from the stack. Assumes that gfont stacks are made up of one gfont and 0 or more non-gfont fonts.
		$first = array_shift( $stack );

		if ( is_null( $first ) ) {
			$stack = array();
		}
	}

	return $stack;
}

/**
 * Generates CSS based on customizer settings.
 *
 * @return string
 */
function gutenbee_get_customizer_css() {
	gutenbee_include_generated_styles_files();

	$generator = Gutenbee_Customizer_CSS_Generator::get_instance();

	$css = '';

	$breakpoints = array(
		'desktop' => '',
		'tablet'  => 991,
		'mobile'  => 575,
	);

	$desktop_min = $breakpoints['tablet'] + 1;
	$tablet_min  = $breakpoints['mobile'] + 1;


	$breakpoint_css = $generator->get( 'desktop' );
	if ( trim( $breakpoint_css ) ) {
		$css .= $breakpoint_css . PHP_EOL;
	}

	$breakpoint_css = $generator->get( 'tablet' );
	if ( trim( $breakpoint_css ) ) {
		$css .= "@media (max-width: {$breakpoints['tablet']}px) {
			{$breakpoint_css}
		}" . PHP_EOL;
	}

	$breakpoint_css = $generator->get( 'desktop-only' );
	if ( trim( $breakpoint_css ) ) {
		$css .= "@media (min-width: {$desktop_min}px) {
			{$breakpoint_css}
		}" . PHP_EOL;
	}

	$breakpoint_css = $generator->get( 'tablet-only' );
	if ( trim( $breakpoint_css ) ) {
		$css .= "@media (min-width: {$tablet_min}px) and (max-width: {$breakpoints['tablet']}px) {
			{$breakpoint_css}
		}" . PHP_EOL;
	}

	// 'mobile' breakpoint only applies to mobile aanyway, but we have 'mobile-only' as well, for completeness.
	// Merge the two under one media query.
	$breakpoint_css  = $generator->get( 'mobile' );
	$breakpoint_css .= $generator->get( 'mobile-only' );
	if ( trim( $breakpoint_css ) ) {
		$css .= "@media (max-width: {$breakpoints['mobile']}px) {
			{$breakpoint_css}
		}" . PHP_EOL;
	}

	return apply_filters( 'gutenbee_customizer_css', $css );
}

function gutenbee_get_all_customizer_css() {
	$styles = array(
		'customizer' => gutenbee_get_customizer_css(),
	);

	$styles = apply_filters( 'gutenbee_all_customizer_css', $styles );

	if ( is_customize_preview() ) {
		$styles[] = '/* Placeholder for preview. */';
	}

	return implode( PHP_EOL, $styles );
}


add_filter( 'gutenbee_customizer_css', 'gutenbee_minimize_css' );
function gutenbee_minimize_css( $css ) {
	$css = preg_replace( '/\s+/', ' ', $css );
	return $css;
}


function gutenbee_should_swap_sidebar_paddings() {
	$layout = gutenbee_get_layout_info_layout();

	if ( is_home() || is_singular( 'post' ) || is_category() || is_tag() || is_author() || is_date() || is_search() ) {
		$base_layout = get_theme_mod( 'blog_layout_archives_layout_type', gutenbee_blog_layout_archives_layout_type_default() );
	} else {
		$layout      = gutenbee_get_layout_info_layout();
		$base_layout = get_theme_mod( 'global_layout_pages_layout_type', gutenbee_global_layout_pages_layout_type_default() );
	}

	$opposite_layouts = array(
		'content_sidebar',
		'sidebar_content',
	);

	if ( in_array( $layout, $opposite_layouts, true ) && in_array( $base_layout, $opposite_layouts, true ) && $base_layout !== $layout ) {
		return true;
	}

	return false;
}

function gutenbee_maybe_swap_sidebar_left_right_paddings( $spacing_control_values ) {
	if ( gutenbee_should_swap_sidebar_paddings() ) {
		foreach ( $spacing_control_values as $breakpoint => $values ) {
			$left  = $values['left'];
			$right = $values['right'];

			$values['left']  = $right;
			$values['right'] = $left;

			$spacing_control_values[ $breakpoint ] = $values;
		}
	}

	return $spacing_control_values;
}
