/**
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Customizer preview changes asynchronously.
 *
 * https://developer.wordpress.org/themes/customize-api/tools-for-improved-user-experience/#using-postmessage-for-improved-setting-previewing
 */

(function ( $ ) {
	//
	// Layout
	//
	wp.customize( 'footer_layout_is_full_width', function ( value ) {
		value.bind( function ( to ) {
			if ( to ) {
				$( '.site-footer' ).addClass( 'footer-fullwidth' );
			} else {
				$( '.site-footer' ).removeClass( 'footer-fullwidth' );
			}
		} );
	} );

	wp.customize( 'footer_layout_padding', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createSpacingControlStyles(
				'footer_layout_padding',
				'.footer-widgets',
				'padding',
				typeof to === 'string' ? JSON.parse( to ) : to
			)
		} );
	} );

	wp.customize( 'footer_layout_widget_title_padding', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createSpacingControlStyles(
				'footer_layout_widget_title_padding',
				'.footer-widgets .widget-title',
				'padding',
				typeof to === 'string' ? JSON.parse( to ) : to
			)
		} );
	} );


	//
	// Colors
	//
	wp.customize( 'footer_colors_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('footer_colors_background', [
				{
					value: to || 'transparent',
					property: 'background-color',
					selectors: '.site-footer',
				},
			]);
		} );
	} );

	wp.customize( 'footer_colors_background_image', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createBackgroundImageStyles(
				'footer_colors_background_image',
				'.site-footer',
				to
			);
		} );
	} );

	wp.customize( 'footer_colors_widget_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('footer_colors_widget_background', [
				{
					value: to || 'transparent',
					property: 'background-color',
					selectors: '.footer-widgets .widget',
				},
				{
					value: to ? '15px' : '0px',
					property: 'padding',
					selectors: '.footer-widgets .widget',
				}
			])
		} );
	} );

	wp.customize( 'footer_colors_widget_border', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('footer_colors_widget_border', [
				{
					value: to || 'transparent',
					property: 'border-color',
					selectors: '.site-footer .widget_meta li a,.site-footer .widget_pages li a,.site-footer .widget_categories li a,.site-footer .widget_archive li a,.site-footer .widget_nav_menu li a,.site-footer .widget_recent_comments li,.site-footer .widget_rss li,.site-footer .widget_recent_entries li,.site-footer input[type="text"],.site-footer input[type="email"],.site-footer input[type="number"],.site-footer input[type="password"],.site-footer input[type="search"],.site-footer input[type="date"],.site-footer select,.site-footer .woocommerce-mini-cart__total',
				},
			]);
		} );
	} );

	wp.customize( 'footer_colors_widget_title', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('footer_colors_widget_title', [
				{
					value: to || 'inherit',
					property: 'color',
					selectors: '.site-footer .widget-title',
				},
				{
					value: to || 'inherit',
					property: 'border-color',
					selectors: '.site-footer .widget .widget-title::after'
				}
			]);
		} );
	} );

	wp.customize( 'footer_colors_widget_title_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('footer_colors_widget_title_background', [
				{
					value: to || 'inherit',
					property: 'background-color',
					selectors: '.footer-widgets .widget-title',
				},
				{
					value: to ? '10px 5px' : '0px',
					property: 'padding',
					selectors: '.footer-widgets .widget-title'
				}
			]);
		} );
	} );

	wp.customize( 'footer_colors_widget_text', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('footer_colors_widget_text', [
				{
					value: to || 'inherit',
					property: 'color',
					selectors: '.footer-widgets .widget',
				},
			]);
		} );
	} );

	wp.customize( 'footer_colors_widget_link', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('footer_colors_widget_link', [
				{
					value: to || 'inherit',
					property: 'color',
					selectors: '.site-footer .widget a, .product_list_widget .product-title',
				},
			]);
		} );
	} );

	wp.customize( 'footer_colors_widget_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('footer_colors_widget_hover', [
				{
					value: to || 'inherit',
					property: 'color',
					selectors: '.site-footer .widget a:hover',
				},
			]);
		} );
	} );


	//
	// Typography
	//
	wp.customize( 'footer_typo_widget_text', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'footer_typo_widget_text',
				'.footer-widgets .widget, .footer-widgets .footer-widgets .product_list_widget .product-title',
				typeof to === 'string' ? JSON.parse( to ) : to
			);
		} );
	} );

	wp.customize( 'footer_typo_widget_title', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'footer_typo_widget_title',
				'.footer-widgets .widget-title',
				typeof to === 'string' ? JSON.parse( to ) : to
			);
		} );
	} );

})( jQuery );
