<?php
/**
 * Jetpack setup function.
 *
 * See: https://jetpack.com/support/infinite-scroll/
 */
function gutenbee_jetpack_setup() {

	$layout = get_theme_mod( 'blog_layout_posts_layout_type', gutenbee_blog_layout_posts_layout_type_default() );

	// Add theme support for Infinite Scroll.
	add_theme_support( 'infinite-scroll', array(
		'container'      => '1col-horz' === $layout ? 'content-row' : 'content-col',
		'render'         => 'gutenbee_infinite_scroll_render',
		'footer'         => false,
		'wrapper'        => false,
		// Jetpack defaults to 7 posts when auto-loading with scroll, which breaks columned layouts.
		'posts_per_page' => get_option( 'posts_per_page' ),
	) );

}
add_action( 'init', 'gutenbee_jetpack_setup' );


/**
 * Custom render function for Infinite Scroll.
 */
function gutenbee_infinite_scroll_render() {
	$layout = get_theme_mod( 'blog_layout_posts_layout_type', gutenbee_blog_layout_posts_layout_type_default() );

	$columns = 1;
	preg_match( '/^\d/', $layout, $matches );
	if ( array_key_exists( 0, $matches ) && intval( $matches[0] ) > 1 ) {
		$columns = intval( $matches[0] );
	}

	$template_part = 'template-parts/article';
	if ( '1col-horz' === $layout ) {
		$template_part = 'template-parts/article-media';
	}

	if ( '1col-horz' === $layout ) {

		while ( have_posts() ) {
			the_post();

			get_template_part( $template_part, get_post_type() );
		}
	} else {
		while ( have_posts() ) {
			the_post();

			?>
			<div class="<?php echo esc_attr( gutenbee_get_blog_columns_classes( $columns ) ); ?>">
				<?php get_template_part( $template_part, get_post_type() ); ?>
			</div>
			<?php

		}
	}
}
