jQuery( document ).ready( function ( $ ) {
	var deactivateAllButtons = function () {
		var $buttons = $('.gutenbee-onboarding-list').find('.button');

		$buttons.addClass('disabled');
	};

	var activateAllButtons = function () {
		var $buttons = $('.gutenbee-onboarding-list').find('.button');

		$buttons.removeClass('disabled');
	};

	$( 'body' ).on( 'click', '.gutenbee-onboarding-wrap .activate-variation', function () {
		var button = $( this );
		var $box   = $( this ).closest( '.gutenbee-variation' );
		var slug   = $( this ).data( 'variation-slug' );

		$.ajax( {
			type: 'post',
			url: gutenbee_onboarding.ajaxurl,
			data: {
				action: 'gutenbee_activate_variation',
				onboarding_nonce: gutenbee_onboarding.onboarding_nonce,
				variation: slug,
			},
			dataType: 'text',
			beforeSend: function() {
				button.addClass( 'updating-message' );
				button.text( gutenbee_onboarding.activating_text );
				deactivateAllButtons();
			},
			success: function( response ) {
				button.removeClass( 'updating-message' );
				button.text( gutenbee_onboarding.activate_variation_text );
				activateAllButtons();
				$( '.gutenbee-variation' ).removeClass( 'enabled' );
				$box.addClass( 'enabled' );
			}
		} );

		return false;
	} );

	$( 'body' ).on( 'click', '.gutenbee-onboarding-wrap .reset-theme-mods', function () {
		var button = $( this );
		var text   = button.text();

		if ( ! window.confirm( gutenbee_onboarding.reset_mods_confirm_text ) ) {
			return false;
		}

		$.ajax( {
			type: 'post',
			url: gutenbee_onboarding.ajaxurl,
			data: {
				action: 'gutenbee_reset_theme_mods',
				onboarding_nonce: gutenbee_onboarding.onboarding_nonce,
			},
			dataType: 'text',
			beforeSend: function() {
				button.addClass( 'updating-message' );
				button.text( gutenbee_onboarding.deleting_text );
				deactivateAllButtons();
			},
			success: function( response ) {
				button.removeClass( 'updating-message' );
				button.text( text );
				activateAllButtons();
			}
		} );

		return false;
	} );

	$( 'body' ).on( 'click', '.gutenbee-onboarding-wrap .install-now', function () {
		var slug = $( this ).attr( 'data-plugin-slug' );

		deactivateAllButtons();

		wp.updates.installPlugin( {
			slug: slug
		}).done(function () {
			activateAllButtons();
		}).fail(function () {
			activateAllButtons();
		});

		return false;
	} );

	var activatePlugin = function ( $activateButton ) {
		if ($activateButton.length) {
			deactivateAllButtons();

			var url = $activateButton.attr( 'href' );
			if (typeof url !== 'undefined') {
				// Request plugin activation.
				$.ajax(
					{
						beforeSend: function () {
							$activateButton.replaceWith( '<a class="button updating-message">' + gutenbee_onboarding.activating_text + '</a>' );
						},
						async: true,
						type: 'GET',
						url: url,
						success: function () {
							// Reload the page.
							location.reload();
						}
					}
				);
			}
		}
	};


	$( document ).on( 'DOMNodeInserted','.activate-now', function () {
		activatePlugin( $(this) );
	} );

	$( document ).on( 'click','.activate-now', function () {
		activatePlugin( $(this) );

		return false;
	} );

	$( '.ajax-install-plugin' ).on( 'click', function( e ) {
		e.preventDefault();
		var button = $(this);
		var plugin_slug = button.data('plugin-slug');

		$.ajax( {
			type: 'post',
			url: gutenbee_onboarding.ajaxurl,
			data: {
				action: 'install_gutenbee_plugin',
				onboarding_nonce: gutenbee_onboarding.onboarding_nonce,
				plugin_slug: plugin_slug,
			},
			dataType: 'text',
			beforeSend: function() {
				button.addClass('updating-message');
				button.text(gutenbee_onboarding.installing_text);
				deactivateAllButtons();
			},
			success: function( response ) {
				button.removeClass('updating-message');
				button.addClass('activate-now button-primary');
				button.text(gutenbee_onboarding.activate_text);
				activateAllButtons();
			}
		} );
	} );

} );
