<?php
/**
 * Gutenbee scripts and styles related functions.
 */

function gutenbee_scripts_styles_suffix() {
	$suffix = '.min';

	if ( ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ||
		( defined( 'WP_DEBUG' ) && WP_DEBUG ) ||
		'none' === get_theme_mod( 'utilities_assets_minify_pack', gutenbee_customizer_defaults( 'utilities_assets_minify_pack' ) )
	) {
		$suffix = '';
	}

	return apply_filters( 'gutenbee_scripts_styles_suffix', $suffix );
}

/**
 * Register scripts and styles unconditionally.
 */
function gutenbee_register_scripts() {
	$suffix = gutenbee_scripts_styles_suffix();

	wp_register_style( 'ci-font-icon', get_theme_file_uri( "/inc/assets/vendor/ci-font-icon/css/ci-font-icon{$suffix}.css" ), array(), gutenbee_asset_version( '1.0.0' ) );

	wp_register_style( 'jquery-magnific-popup', get_theme_file_uri( "/inc/assets/vendor/magnific/magnific{$suffix}.css" ), array(), gutenbee_asset_version( '1.0.0' ) );
	wp_register_script( 'jquery-magnific-popup', get_theme_file_uri( "/inc/assets/vendor/magnific/jquery.magnific-popup{$suffix}.js" ), array( 'jquery' ), gutenbee_asset_version( '1.0.0' ), true );
	wp_register_script( 'gutenbee-magnific-init', get_theme_file_uri( "/js/magnific-init{$suffix}.js" ), array( 'jquery' ), gutenbee_asset_version(), true );

	wp_register_style( 'gutenbee-woocommerce', get_theme_file_uri( "/css/woocommerce{$suffix}.css" ), array(), gutenbee_asset_version() );

	wp_register_style( 'gutenbee-dependencies', false, array(
		'ci-font-icon',
	), gutenbee_asset_version() );


	$main_dependencies = array(
		'gutenbee-dependencies',
	);

	if ( class_exists( 'WooCommerce' ) ) {
		$main_dependencies = array_merge( $main_dependencies, array(
			'gutenbee-woocommerce',
		) );
	}

	if ( is_child_theme() ) {
		wp_register_style( 'gutenbee-style-parent', get_template_directory_uri() . "/style{$suffix}.css", $main_dependencies, gutenbee_asset_version() );
	}

	wp_register_style( 'gutenbee-style', get_stylesheet_uri(), $main_dependencies, gutenbee_asset_version() );

	wp_register_script( 'jquery-sticky', get_theme_file_uri( "/inc/assets/vendor/jquery.sticky/jquery.sticky{$suffix}.js" ), array( 'jquery' ), gutenbee_asset_version( '1.0.4' ), true );
	wp_register_script( 'mobile-detect', get_theme_file_uri( "/inc/assets/vendor/mobile-detect/mobile-detect{$suffix}.js" ), array(), gutenbee_asset_version( '1.4.3' ), true );
	wp_register_script( 'gutenbee-woocommerce', get_theme_file_uri( "/js/woocommerce{$suffix}.js" ), array( 'jquery' ), gutenbee_asset_version(), true );

	wp_register_script( 'gutenbee-dependencies', false, array(
		'jquery',
	), gutenbee_asset_version(), true );

	$main_dependencies = array(
		'gutenbee-dependencies',
	);

	if ( class_exists( 'WooCommerce' ) ) {
		$main_dependencies = array_merge( $main_dependencies, array(
			'gutenbee-woocommerce',
		) );
	}

	if ( gutenbee_get_mod( 'header_layout_menu_is_sticky', gutenbee_customizer_defaults( 'header_layout_menu_is_sticky' ) ) ) {
		// Load mobile-detect only when sticky on mobile is disabled.
		if ( ! gutenbee_get_mod( 'header_layout_menu_is_sticky_mobile_enabled', gutenbee_customizer_defaults( 'header_layout_menu_is_sticky_mobile_enabled' ) ) ) {
			$main_dependencies = array_merge( $main_dependencies, array(
				'mobile-detect',
			) );
		}

		$main_dependencies = array_merge( $main_dependencies, array(
			'jquery-sticky',
		) );
	}

	wp_register_script( 'gutenbee-front-scripts', get_theme_file_uri( "/js/scripts{$suffix}.js" ), $main_dependencies, gutenbee_asset_version(), true );

}
add_action( 'wp', 'gutenbee_register_scripts' );

/**
 * Enqueue scripts and styles.
 */
function gutenbee_enqueue_scripts() {
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( get_theme_mod( 'utilities_lightbox', gutenbee_customizer_defaults( 'utilities_lightbox' ) ) ) {
		wp_enqueue_style( 'jquery-magnific-popup' );
		wp_enqueue_script( 'jquery-magnific-popup' );
		wp_enqueue_script( 'gutenbee-magnific-init' );
	}

	if ( is_child_theme() ) {
		wp_enqueue_style( 'gutenbee-style-parent' );
	}

	// Load the user-selected google fonts, if any.
	gutenbee_enqueue_google_fonts();

	wp_enqueue_style( 'gutenbee-style' );

	$customizer_css_handle = is_child_theme() ? 'gutenbee-style-parent' : 'gutenbee-style';
	wp_add_inline_style( $customizer_css_handle, gutenbee_get_all_customizer_css() );


	wp_enqueue_script( 'gutenbee-front-scripts' );
}
add_action( 'wp_enqueue_scripts', 'gutenbee_enqueue_scripts' );

/**
 * Enqueue admin scripts and styles.
 */
function gutenbee_admin_scripts( $hook ) {
	$suffix = gutenbee_scripts_styles_suffix();

	wp_register_script( 'wp-color-picker-alpha', get_theme_file_uri( "/inc/assets/vendor/wp-color-picker-alpha/wp-color-picker-alpha{$suffix}.js" ), array(
		'jquery',
		'wp-color-picker',
	), gutenbee_asset_version( '2.0' ), true );

	wp_register_style( 'gutenbee-post-meta', get_theme_file_uri( "/css/admin/meta{$suffix}.css" ), array(), gutenbee_asset_version() );

	//
	// Enqueue
	//

	if ( in_array( $hook, array( 'post.php', 'post-new.php' ), true ) ) {
		wp_enqueue_style( 'gutenbee-post-meta' );
	}
}
add_action( 'admin_enqueue_scripts', 'gutenbee_admin_scripts' );
