<?php
/**
 * Custom template tags for this theme
 */

add_action( 'gutenbee_the_post_header', 'gutenbee_the_post_entry_title', 10 );
add_action( 'gutenbee_the_post_header', 'gutenbee_the_post_entry_meta', 20 );

add_action( 'gutenbee_the_post_entry_meta', 'gutenbee_the_post_entry_sticky_label', 10 );
add_action( 'gutenbee_the_post_entry_meta', 'gutenbee_the_post_entry_date', 20 );
add_action( 'gutenbee_the_post_entry_meta', 'gutenbee_the_post_entry_categories', 30 );
add_action( 'gutenbee_the_post_entry_meta', 'gutenbee_the_post_entry_author', 40 );
add_action( 'gutenbee_the_post_entry_meta', 'gutenbee_the_post_entry_comments_link', 50 );

/**
 * Displays the appropriate header template according to the selected option.
 */
function gutenbee_header() {
	$header_info = explode( '_', gutenbee_get_mod( 'header_layout_menu_type', gutenbee_customizer_defaults( 'header_layout_menu_type' ) ) );
	$header_type = $header_info[0];

	do_action( 'gutenbee_before_header', $header_type );

	get_template_part( "template-parts/header/header-{$header_type}" );

	do_action( 'gutenbee_after_header', $header_type );
}

/**
 * Echoes header classes based on customizer options
 */
function gutenbee_the_header_classes() {
	$classes = array(
		'site-header',
		get_theme_mod( 'header_layout_is_full_width', gutenbee_customizer_defaults( 'header_layout_is_full_width' ) ) ? 'header-fullwidth' : '',
		gutenbee_get_mod( 'header_layout_menu_is_sticky', gutenbee_customizer_defaults( 'header_layout_menu_is_sticky' ) ) ? 'header-sticky' : '',
		gutenbee_get_mod( 'header_layout_menu_is_sticky_mobile_enabled', gutenbee_customizer_defaults( 'header_layout_menu_is_sticky_mobile_enabled' ) ) ? '' : 'header-sticky-mobile-disabled',
	);

	$header_info = explode( '_', gutenbee_get_mod( 'header_layout_menu_type', gutenbee_customizer_defaults( 'header_layout_menu_type' ) ) );

	switch ( $header_info[0] ) {
		case 'full':
			$classes[] = 'header-full';
			$classes[] = "header-full-nav-{$header_info[1]}";
			break;
		case 'split':
			$classes[] = 'header-nav-split';
			break;
		case 'navbar':
			$classes[] = 'header-navbar';

			if ( 'top' === $header_info[1] ) {
				$classes[] = 'header-navbar-v-reverse';
			}

			switch ( $header_info[2] ) {
				case 'center':
					$classes[] = 'header-navbar-h-center';
					break;
				case 'right':
					$classes[] = 'header-navbar-h-reverse';
					break;
			}

			break;
	}

	if ( get_theme_mod( 'header_layout_is_menu_stretched', gutenbee_customizer_defaults( 'header_layout_is_menu_stretched' ) ) ) {
		$applicable_layouts = array(
			'navbar_top_left',
			'navbar_top_center',
			'navbar_top_right',
			'navbar_bottom_left',
			'navbar_bottom_center',
			'navbar_bottom_right',
		);
		if ( in_array( gutenbee_get_mod( 'header_layout_menu_type', gutenbee_customizer_defaults( 'header_layout_menu_type' ) ), $applicable_layouts, true ) ) {
			$classes[] = 'header-navbar-stretch';
		}
	}

	if ( 'transparent' === gutenbee_get_mod( 'header_layout_type', gutenbee_customizer_defaults( 'header_layout_type' ) ) ) {
		$classes[] = 'header-fixed';
	}


	$classes = apply_filters( 'gutenbee_header_classes', $classes );

	$classes = array_filter( $classes );

	echo esc_attr( implode( ' ', $classes ) );
}

/**
 * Echoes the logo / site title / description, depending on customizer options.
 */
function gutenbee_the_site_branding() {
	do_action( 'gutenbee_before_site_branding' );

	get_template_part( 'template-parts/header/site-branding' );

	do_action( 'gutenbee_after_site_branding' );
}

/**
 * Displays the footer template.
 */
function gutenbee_footer() {
	do_action( 'gutenbee_before_footer' );

	get_template_part( 'template-parts/footer/footer' );

	do_action( 'gutenbee_after_footer' );
}

/**
 * Echoes footer classes based on customizer options
 */
function gutenbee_the_footer_classes() {
	$classes = apply_filters( 'gutenbee_footer_classes', array(
		'site-footer',
		get_theme_mod( 'footer_layout_is_full_width', gutenbee_customizer_defaults( 'footer_layout_is_full_width' ) ) ? 'footer-fullwidth' : '',
	) );

	$classes = array_filter( $classes );

	echo esc_attr( implode( ' ', $classes ) );
}

/**
 * Displays the current post's feature image (if applicable), using the appropriate markup in listings and singulars.
 * Must be used within the loop.
 *
 * @param string|false $size Image size name. Default 'post-thumbnail'.
 */
function gutenbee_the_post_thumbnail( $size = false ) {
	if ( ! $size ) {
		$size = 'post-thumbnail';
	}

	if ( ! has_post_thumbnail() ) {
		return;
	}

	do_action( 'gutenbee_before_the_post_thumbnail' );

	if ( is_singular() && get_the_ID() === get_queried_object_id() ) {
		if ( get_theme_mod( 'blog_content_single_post_is_featured_visible', gutenbee_customizer_defaults( 'blog_content_single_post_is_featured_visible' ) ) ) {
			$layout_info = gutenbee_get_layout_info();
			if ( 'col-12' === $layout_info['container_classes'] ) {
				$size = 'gutenbee_item_lg';
			}

			$caption = gutenbee_get_image_lightbox_caption( get_post_thumbnail_id() );
			?>
			<figure class="entry-thumb">
				<a class="gutenbee-lightbox" href="<?php echo esc_url( get_the_post_thumbnail_url( get_the_ID(), 'large' ) ); ?>" title="<?php echo esc_attr( $caption ); ?>">
					<?php the_post_thumbnail( $size ); ?>
				</a>
			</figure>
			<?php
		}
	} else {
		if ( get_theme_mod( 'blog_content_archives_is_featured_visible', gutenbee_customizer_defaults( 'blog_content_archives_is_featured_visible' ) ) ) {
			?>
			<figure class="entry-thumb">
				<a href="<?php the_permalink(); ?>">
					<?php the_post_thumbnail( $size ); ?>
				</a>
			</figure>
			<?php
		}
	}

	do_action( 'gutenbee_after_the_post_thumbnail' );
}

/**
 * Displays the current post's header (title, meta, etc).
 */
function gutenbee_the_post_header() {
	if ( (int) gutenbee_get_post_meta( get_queried_object_id(), 'gutenbee_hide_single_title', 0 ) ) {
		return;
	}

	ob_start();

	/**
	 * gutenbee_the_post_header hook.
	 *
	 * @hooked gutenbee_the_post_entry_title - 10
	 * @hooked gutenbee_the_post_entry_meta - 20
	 */
	do_action( 'gutenbee_the_post_header' );

	$html = ob_get_clean();

	if ( trim( $html ) ) {
		$html = sprintf( '<header class="entry-header">%s</header>', $html );
	}

	do_action( 'gutenbee_before_the_post_header', $html );

	echo $html; // phpcs:ignore WordPress.Security.EscapeOutput

	do_action( 'gutenbee_after_the_post_header', $html );
}

/**
 * Displays the current post's title, using the appropriate markup in listings and singulars.
 */
function gutenbee_the_post_entry_title() {
	if ( is_singular() && get_the_ID() === get_queried_object_id() ) {
		if ( is_singular( 'post' ) ) {
			gutenbee_the_single_post_title( 'entry-title' );
		} else {
			?><h1 class="entry-title"><?php the_title(); ?></h1><?php
		}
	} else {
		if ( get_theme_mod( 'blog_content_archives_is_title_visible', gutenbee_customizer_defaults( 'blog_content_archives_is_title_visible' ) ) ) {
			gutenbee_the_archive_post_title( 'entry-title' );
		}
	}
}

/**
 * Displays the current post's meta.
 */
function gutenbee_the_post_entry_meta() {
	ob_start();

	/**
	 * gutenbee_the_post_entry_meta hook.
	 *
	 * @hooked gutenbee_the_post_entry_sticky_label - 10
	 * @hooked gutenbee_the_post_entry_date - 20
	 * @hooked gutenbee_the_post_entry_categories - 30
	 * @hooked gutenbee_the_post_entry_author - 40
	 * @hooked gutenbee_the_post_entry_comments_link - 50
	 */
	do_action( 'gutenbee_the_post_entry_meta' );

	$html = ob_get_clean();

	if ( trim( $html ) ) {
		$html = sprintf( '<div class="entry-meta">%s</div>', $html );
	}

	do_action( 'gutenbee_before_the_post_entry_meta', $html );

	echo $html; // phpcs:ignore WordPress.Security.EscapeOutput

	do_action( 'gutenbee_after_the_post_entry_meta', $html );
}

/**
 * Displays the current post's sticky label (if applicable).
 */
function gutenbee_the_post_entry_sticky_label() {
	if ( 'post' !== get_post_type() ) {
		return;
	}

	if (
		( ! is_singular() && is_sticky() && is_home() && ! is_paged() && get_theme_mod( 'blog_content_archives_is_meta_sticky_visible', gutenbee_customizer_defaults( 'blog_content_archives_is_meta_sticky_visible' ) ) )
		||
		( is_singular() && is_sticky() && get_theme_mod( 'blog_content_single_post_is_meta_sticky_visible', gutenbee_customizer_defaults( 'blog_content_single_post_is_meta_sticky_visible' ) ) )
	) {
		?>
		<span class="entry-meta-item entry-sticky">
			<?php esc_html_e( 'Featured', 'gutenbee' ); ?>
		</span>
		<?php
	}
}

/**
 * Displays the current post's date (if applicable).
 */
function gutenbee_the_post_entry_date() {
	if ( 'post' !== get_post_type() ) {
		return;
	}

	if (
		( ! is_singular() && get_theme_mod( 'blog_content_archives_is_meta_date_visible', gutenbee_customizer_defaults( 'blog_content_archives_is_meta_date_visible' ) ) )
		||
		( is_singular() && get_theme_mod( 'blog_content_single_post_is_meta_date_visible', gutenbee_customizer_defaults( 'blog_content_single_post_is_meta_date_visible' ) ) )
	) {
		?>
		<span class="entry-meta-item">
			<time datetime="<?php echo esc_attr( get_the_date( 'c' ) ); ?>"><?php echo get_the_date(); ?></time>
		</span>
		<?php
	}
}

/**
 * Displays the current post's categories (if applicable).
 */
function gutenbee_the_post_entry_categories() {
	if ( 'post' !== get_post_type() ) {
		return;
	}

	if (
		( ! is_singular() && get_theme_mod( 'blog_content_archives_is_meta_categories_visible', gutenbee_customizer_defaults( 'blog_content_archives_is_meta_categories_visible' ) ) )
		||
		( is_singular() && get_theme_mod( 'blog_content_single_post_is_meta_categories_visible', gutenbee_customizer_defaults( 'blog_content_single_post_is_meta_categories_visible' ) ) )
	) {
		?>
		<span class="entry-meta-item entry-categories">
			<?php the_category( ', ' ); ?>
		</span>
		<?php
	}
}

/**
 * Displays the current post's author (if applicable).
 */
function gutenbee_the_post_entry_author() {
	if ( 'post' !== get_post_type() ) {
		return;
	}

	if (
		( ! is_singular() && get_theme_mod( 'blog_content_archives_is_meta_author_visible', gutenbee_customizer_defaults( 'blog_content_archives_is_meta_author_visible' ) ) )
		||
		( is_singular() && get_theme_mod( 'blog_content_single_post_is_meta_author_visible', gutenbee_customizer_defaults( 'blog_content_single_post_is_meta_author_visible' ) ) )
	) {
		?>
		<span class="entry-meta-item entry-author">
			<?php
				printf(
					/* translators: %s is the author's name. */
					esc_html_x( 'by %s', 'post author', 'gutenbee' ),
					'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
				);
			?>
		</span>
		<?php
	}
}

/**
 * Displays the current post's comments link (if applicable).
 */
function gutenbee_the_post_entry_comments_link() {
	if ( 'post' !== get_post_type() ) {
		return;
	}

	if (
		( ! is_singular() && get_theme_mod( 'blog_content_archives_is_meta_comments_visible', gutenbee_customizer_defaults( 'blog_content_archives_is_meta_comments_visible' ) ) )
		||
		( is_singular() && get_theme_mod( 'blog_content_single_post_is_meta_comments_visible', gutenbee_customizer_defaults( 'blog_content_single_post_is_meta_comments_visible' ) ) )
	) {
		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			?>
			<span class="entry-meta-item entry-comments-link">
				<?php
					/* translators: %s: post title */
					comments_popup_link( sprintf( wp_kses( __( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'gutenbee' ), array(
						'span' => array(
							'class' => array(),
						),
					) ), get_the_title() ) );
				?>
			</span>
			<?php
		}
	}
}

/**
 * Displays the current post's tags (if applicable).
 */
function gutenbee_the_post_tags() {
	if ( 'post' !== get_post_type() ) {
		return;
	}

	if ( has_tag() && get_theme_mod( 'blog_content_single_post_is_tags_visible', gutenbee_customizer_defaults( 'blog_content_single_post_is_tags_visible' ) ) ) {
		?>
		<div class="entry-tags">
			<?php the_tags( '', ' ' ); ?>
		</div>
		<?php
	}
}

/**
 * Displays the authorbox template.
 */
function gutenbee_the_post_author_box() {

	do_action( 'gutenbee_before_the_post_author_box' );

	get_template_part( 'template-parts/authorbox' );

	do_action( 'gutenbee_after_the_post_author_box' );
}

/**
 * Displays the current post's title according to customizer options, suitable for use in blog listings.
 *
 * @param string $class Additional html classes.
 */
function gutenbee_the_archive_post_title( $class = 'ci-item-title' ) {
	echo wp_kses_post( sprintf( '<%1$s class="%2$s"><a href="%3$s">%4$s</a></%1$s>',
		get_theme_mod( 'blog_typo_archives_title_tag', gutenbee_customizer_defaults( 'blog_typo_archives_title_tag' ) ),
		esc_attr( $class ),
		esc_url( get_the_permalink() ),
		get_the_title()
	) );
}

/**
 * Displays the current post's title according to customizer options, suitable for use in blog singles.
 *
 * @param string $class Additional html classes.
 */
function gutenbee_the_single_post_title( $class = 'ci-item-title' ) {
	echo wp_kses_post( sprintf( '<%1$s class="%2$s">%3$s</%1$s>',
		get_theme_mod( 'blog_typo_single_post_title_tag', gutenbee_customizer_defaults( 'blog_typo_single_post_title_tag' ) ),
		esc_attr( $class ),
		get_the_title()
	) );
}


/**
 * Echoes pagination links if applicable. Output depends on pagination method selected from the customizer.
 *
 * @uses the_post_pagination()
 * @uses previous_posts_link()
 * @uses next_posts_link()
 *
 * @param array $args An array of arguments to change default behavior.
 * @param WP_Query|null $query A WP_Query object to paginate. Defaults to null and uses the global $wp_query
 *
 * @return void
 */
function gutenbee_posts_pagination( $args = array() ) {
	$args = wp_parse_args( $args, apply_filters( 'gutenbee_posts_pagination_default_args', array(
		'mid_size'           => 1,
		'prev_text'          => _x( 'Previous', 'previous post', 'gutenbee' ),
		'next_text'          => _x( 'Next', 'next post', 'gutenbee' ),
		'screen_reader_text' => __( 'Posts navigation', 'gutenbee' ),
		'container_id'       => '',
		'container_class'    => '',
	) ) );

	$output = '';
	$method = get_theme_mod( 'blog_layout_archives_pagination', gutenbee_archives_pagination_default() );

	switch ( $method ) {
		case 'prevnext':
			$output = get_the_posts_navigation( $args );
			break;
		case 'numbers':
		default:
			$output = get_the_posts_pagination( $args );
			break;
	}

	if ( ! empty( $output ) && ! empty( $args['container_id'] ) || ! empty( $args['container_class'] ) ) {
		$output = sprintf( '<div id="%2$s" class="%3$s">%1$s</div>', $output, esc_attr( $args['container_id'] ), esc_attr( $args['container_class'] ) );
	}

	// All markup is from native WordPress functions. The wrapping div is properly escaped above.
	$output_safe = $output;

	echo $output_safe;
}

/**
 * Echoes row classes based on whether the current template has a visible sidebar or not,
 * and depending on sidebar visibility option on single post/pages/etc.
 */
function gutenbee_the_row_classes() {
	$info = gutenbee_get_layout_info();
	echo esc_attr( $info['row_classes'] );
}

/**
 * Echoes container classes based on whether
 * the current template has a visible sidebar or not
 */
function gutenbee_the_container_classes() {
	$info = gutenbee_get_layout_info();
	echo esc_attr( $info['container_classes'] );
}

/**
 * Echoes container classes based on whether
 * the current template has a visible sidebar or not
 */
function gutenbee_the_sidebar_classes() {
	$info = gutenbee_get_layout_info();
	echo esc_attr( $info['sidebar_classes'] );
}

/**
 * Displays the site search button and the global search form.
 * The first call to this function outputs the markup for both the form and the button,
 * while subsequent calls only output the button's markup.
 */
function gutenbee_the_site_search() {
	static $displayed = false;

	if ( ! $displayed ) {
		?>
		<form action="<?php echo esc_url( home_url( '/' ) ); ?>" method="get" class="global-search-form" role="search">
			<label for="global-search-input" class="sr-only"><?php esc_html_e( 'Search for:', 'gutenbee' ); ?></label>
			<input type="search" id="global-search-input" name="s" class="global-search-input" value="<?php echo get_search_query(); ?>" placeholder="<?php echo esc_attr_x( 'Type and hit enter to search', 'search box placeholder', 'gutenbee' ); ?>">
			<button type="submit" class="global-search-form-submit"><?php esc_html_e( 'Search', 'gutenbee' ); ?></button>
			<button type="button" class="global-search-form-dismiss" data-set-focus=".global-search-input">&times;</button>
		</form>
		<?php

		$displayed = true;
	}

	?>
	<a href="#" class="global-search-form-trigger">
		<i class="ci-font-icon ci-font-icon-search"></i> <span class="sr-only"><?php esc_html_e( 'Expand search form', 'gutenbee' ); ?></span>
	</a>
	<?php
}

/**
 * Displays a shopping minicart button if applicable.
 */
function gutenbee_the_minicart_button() {
	if ( ! class_exists( 'WooCommerce' ) ) {
		return '';
	}
	?>
	<div class="head-mini-cart-wrap">
		<div class="header-mini-cart">
			<a href="#" class="header-mini-cart-trigger">
				<?php gutenbee_minicart_button_trigger_text(); ?>
			</a>

			<div class="header-mini-cart-contents">

				<aside class="widget woocommerce widget_shopping_cart">
					<h3 class="widget-title"><?php esc_html_e( 'Cart', 'gutenbee' ); ?></h3>

					<div class="widget_shopping_cart_content">
						<?php woocommerce_mini_cart(); ?>

						<p class="buttons">
							<a href="<?php echo esc_url( wc_get_cart_url() ); ?>" class="button wc-forward"><?php esc_html_e( 'View Cart', 'gutenbee' ); ?></a>
							<a href="<?php echo esc_url( wc_get_checkout_url() ); ?>" class="button checkout wc-forward"><?php esc_html_e( 'Checkout', 'gutenbee' ); ?></a>
						</p>
					</div>
				</aside>

			</div>
		</div>
	</div>
	<?php
}

function gutenbee_minicart_button_trigger_text() {
	// This span.header-mini-cart-trigger-text is needed for cart fragments updates.
	// Do not remove or modify without modifying the respective fragment code also.
	?>
	<span class="header-mini-cart-trigger-text">
		<i class="ci-font-icon ci-font-icon-shopping-cart"></i>
		<span class="header-mini-cart-count">
			<?php echo esc_html( WC()->cart->get_cart_contents_count() ); ?>
		</span>
	</span><?php
}
